<?php
/**
 * A filter for detecting email changes
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class EmailChangeFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance			An instance of this filter class
	 */
	public final static function createEmailChangeFilter () {
		// Get a new instance
		$filterInstance = new EmailChangeFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Implement email change of the user here. HINT: Use the User class!
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get both emails
		$email1 = $requestInstance->getRequestElement('email1');
		$email2 = $requestInstance->getRequestElement('email2');

		// Is only first email set?
		if ((!empty($email1)) && (empty($email2))) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Email 2 is empty
			$responseInstance->addFatalMessage('email2_empty');

			// Stop processing here
			return false;
		} // END - if

		// Is only second email set?
		if ((empty($email1)) && (!empty($email2))) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Email 1 is empty
			$responseInstance->addFatalMessage('email1_empty');

			// Stop processing here
			return false;
		} // END - if

		// Do both match?
		if ($email1 != $email2) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Emails are mismatching
			$responseInstance->addFatalMessage('emails_mismatch');

			// Stop processing here
			return false;
		} // END - if

		// Are email and confirmation empty?
		if ((empty($email1)) && (empty($email2))) {
			// No email change required!
			return true;
		} // END - if

		// Now, get a user instance for comparison
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Get the email field
		$userEmail = $userInstance->getField('email');

		// Are they different?
		if ($userEmail == $email1) {
			// Nothing has been changed is fine...
			return true;
		} // END - if

		// Update the "new_email" field
		$this->partialStub("Unfinished part.");
	}
}

// [EOF]
?>
